package cn.com.qmth.stmms.biz.report.model;

import java.io.Serializable;
import java.util.LinkedList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Index;
import javax.persistence.Table;

import org.apache.commons.lang3.StringUtils;

import cn.com.qmth.stmms.common.annotation.ExcelField;

/**
 * 课程总量分析
 *
 * @author xuwenjin
 * @date 2019-04-11
 */
@Entity
@Table(name = "s_basic_subject", indexes = { @Index(name = "subject_index", columnList = "exam_id,subject_code") })
public class ReportSubject implements Serializable {

    private static final long serialVersionUID = -1596478079357284914L;

    // 数据库中多个单元紧凑保存的拼接符
    public static final String DB_ITEM_JOINER = ",";

    /**
     * 主键
     */
    @Id
    @GeneratedValue
    private Integer id;

    /**
     * 考试id
     */
    @Column(name = "exam_id")
    private Integer examId;

    /**
     * 课程编号
     */
    @ExcelField(title = "课程代码", align = 2, sort = 10)
    @Column(name = "subject_code")
    private String subjectCode;

    /**
     * 课程名称
     */
    @ExcelField(title = "课程名称", align = 2, sort = 20)
    @Column(name = "subject_name")
    private String subjectName;

    /**
     * 最高分
     */
    @ExcelField(title = "最高分", align = 2, sort = 30)
    @Column(name = "max_score")
    private Double maxScore;

    /**
     * 最低分
     */
    @ExcelField(title = "最低分", align = 2, sort = 40)
    @Column(name = "min_score")
    private Double minScore;

    /**
     * 平均分
     */
    @ExcelField(title = "平均分", align = 2, sort = 50)
    @Column(name = "avg_score")
    private Double avgScore;

    /**
     * 报考人数
     */
    @ExcelField(title = "报考人数", align = 2, sort = 60)
    @Column(name = "total_count")
    private Integer totalCount;

    /**
     * 及格人数
     */
    @ExcelField(title = "及格人数", align = 2, sort = 70)
    @Column(name = "pass_count")
    private Integer passCount;

    /**
     * 及格率
     */
    @ExcelField(title = "及格率(%)", align = 2, sort = 80)
    @Column(name = "pass_rate")
    private Double passRate;

    /**
     * 缺考人数
     */
    @ExcelField(title = "缺考人数", align = 2, sort = 90)
    @Column(name = "absent_count")
    private Integer absentCount;

    /**
     * 违纪人数
     */
    @ExcelField(title = "违纪人数", align = 2, sort = 100)
    @Column(name = "breach_count")
    private Integer breachCount;

    /**
     * 实考人数
     */
    @ExcelField(title = "实考人数", align = 2, sort = 110)
    @Column(name = "reality_count")
    private Integer realityCount;

    /**
     * 分段统计
     */
    @Column(name = "score_range", nullable = true)
    private String scoreRange;

    /**
     * 所有选项
     */
    @Column(name = "options", nullable = true)
    private String options;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getExamId() {
        return examId;
    }

    public void setExamId(Integer examId) {
        this.examId = examId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public Double getMaxScore() {
        return maxScore;
    }

    public void setMaxScore(Double maxScore) {
        this.maxScore = maxScore;
    }

    public Double getMinScore() {
        return minScore;
    }

    public void setMinScore(Double minScore) {
        this.minScore = minScore;
    }

    public Double getAvgScore() {
        return avgScore;
    }

    public void setAvgScore(Double avgScore) {
        this.avgScore = avgScore;
    }

    public Integer getTotalCount() {
        return totalCount;
    }

    public void setTotalCount(Integer totalCount) {
        this.totalCount = totalCount;
    }

    public Integer getPassCount() {
        return passCount;
    }

    public void setPassCount(Integer passCount) {
        this.passCount = passCount;
    }

    public Double getPassRate() {
        return passRate;
    }

    public void setPassRate(Double passRate) {
        this.passRate = passRate;
    }

    public Integer getAbsentCount() {
        return absentCount;
    }

    public void setAbsentCount(Integer absentCount) {
        this.absentCount = absentCount;
    }

    public Integer getBreachCount() {
        return breachCount;
    }

    public void setBreachCount(Integer breachCount) {
        this.breachCount = breachCount;
    }

    public Integer getRealityCount() {
        return realityCount;
    }

    public void setRealityCount(Integer realityCount) {
        this.realityCount = realityCount;
    }

    public String getScoreRange() {
        return scoreRange;
    }

    public void setScoreRange(String scoreRange) {
        this.scoreRange = scoreRange;
    }

    public String getOptions() {
        return options;
    }

    public void setOptions(String options) {
        this.options = options;
    }

    public void addOptions(String option) {
        options = StringUtils.trimToNull(options);
        StringBuilder sb = new StringBuilder(options);
        if (options != null) {
            sb.append(DB_ITEM_JOINER);
        }
        sb.append(option);
        this.options = sb.toString();
    }

    public List<String> getOptionList() {
        List<String> list = new LinkedList<String>();
        options = StringUtils.trimToEmpty(options);
        String[] values = StringUtils.split(options, DB_ITEM_JOINER);
        for (String value : values) {
            list.add(value);
        }
        return list;
    }
}