package cn.com.qmth.stmms.biz.report.model;

import net.sf.json.JSONObject;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * 
 * @Description: 统计配置项
 * @author ting.yin
 * @date 2019年6月18日
 */
@Component
public class SasConfigItem {

    // 及格分数
    @Value("${sas.passScore}")
    private Double passScore;

    // 优秀分数
    @Value("${sas.excellentScore}")
    private Double excellentScore;

    // 区分度优
    @Value("${sas.discriminationExcellentScore}")
    private Double discriminationExcellentScore;

    // 区分度良
    @Value("${sas.discriminationGoodScore}")
    private Double discriminationGoodScore;

    // 区分度可
    @Value("${sas.discriminationGeneralScore}")
    private Double discriminationGeneralScore;

    // 区分度差
    @Value("${sas.discriminationBadScore}")
    private Double discriminationBadScore;

    // 难度高
    @Value("${sas.difficultyHighScore}")
    private Double difficultyHighScore;

    // 难度中
    @Value("${sas.difficultyMiddleScore}")
    private Double difficultyMiddleScore;

    // 难度低
    @Value("${sas.difficultyLowScore}")
    private Double difficultyLowScore;

    // 高分段
    @Value("${sas.highScore}")
    private Double highScore;

    // 低分段
    @Value("${sas.lowScore}")
    private Double lowScore;

    public SasConfigItem() {

    }

    public SasConfigItem(String text) {
        text = StringUtils.trimToEmpty(text);
        try {
            JSONObject jsonObject = JSONObject.fromObject(text);
            lowScore = jsonObject.getDouble("lowScore");
        } catch (Exception e) {
            throw new IllegalArgumentException("Invalid SasConfigItem init text:" + text);
        }
    }

    public static SasConfigItem parse(SasConfigItem configItem, String text) {
        SasConfigItem item = new SasConfigItem(text);
        if (item.getDifficultyHighValue() != null) {
            configItem.setDifficultyHighScore(item.getDifficultyHighValue());
        }
        if (item.getDifficultyLowValue() != null) {
            configItem.setDifficultyLowScore(item.getDifficultyLowValue());
        }
        if (item.getDifficultyMiddleValue() != null) {
            configItem.setDifficultyMiddleScore(item.getDifficultyMiddleValue());
        }
        if (item.getDiscriminationBadValue() != null) {
            configItem.setDiscriminationBadScore(item.getDiscriminationBadValue());
        }
        if (item.getDiscriminationExcellentValue() != null) {
            configItem.setDiscriminationExcellentScore(item.getDiscriminationExcellentValue());
        }
        if (item.getDiscriminationGoodValue() != null) {
            configItem.setDiscriminationGoodScore(item.getDiscriminationGoodValue());
        }
        if (item.getDiscriminationGeneralValue() != null) {
            configItem.setDiscriminationGeneralScore(item.getDiscriminationGeneralValue());
        }
        if (item.getHighScore() != null) {
            configItem.setHighScore(item.getHighScore());
        }
        if (item.getLowScore() != null) {
            configItem.setLowScore(item.getLowScore());
        }
        if (item.getExcellentScore() != null) {
            configItem.setExcellentScore(item.getExcellentScore());
        }
        if (item.getPassScore() != null) {
            configItem.setPassScore(item.getPassScore());
        }
        return configItem;
    }

    public Double getPassScore() {
        return passScore;
    }

    public void setPassScore(Double passScore) {
        this.passScore = passScore;
    }

    public Double getExcellentScore() {
        return excellentScore;
    }

    public void setExcellentScore(Double excellentScore) {
        this.excellentScore = excellentScore;
    }

    public Double getDiscriminationExcellentValue() {
        return discriminationExcellentScore;
    }

    public void setDiscriminationExcellentScore(Double discriminationExcellentScore) {
        this.discriminationExcellentScore = discriminationExcellentScore;
    }

    public Double getDiscriminationGoodValue() {
        return discriminationGoodScore;
    }

    public void setDiscriminationGoodScore(Double discriminationGoodScore) {
        this.discriminationGoodScore = discriminationGoodScore;
    }

    public Double getDiscriminationGeneralValue() {
        return discriminationGeneralScore;
    }

    public void setDiscriminationGeneralScore(Double discriminationGeneralScore) {
        this.discriminationGeneralScore = discriminationGeneralScore;
    }

    public Double getDiscriminationBadValue() {
        return discriminationBadScore;
    }

    public void setDiscriminationBadScore(Double discriminationBadScore) {
        this.discriminationBadScore = discriminationBadScore;
    }

    public Double getDifficultyHighValue() {
        return difficultyHighScore;
    }

    public void setDifficultyHighScore(Double difficultyHighScore) {
        this.difficultyHighScore = difficultyHighScore;
    }

    public Double getDifficultyMiddleValue() {
        return difficultyMiddleScore;
    }

    public void setDifficultyMiddleScore(Double difficultyMiddleScore) {
        this.difficultyMiddleScore = difficultyMiddleScore;
    }

    public Double getDifficultyLowValue() {
        return difficultyLowScore;
    }

    public void setDifficultyLowScore(Double difficultyLowScore) {
        this.difficultyLowScore = difficultyLowScore;
    }

    public Double getHighScore() {
        return highScore;
    }

    public void setHighScore(Double highScore) {
        this.highScore = highScore;
    }

    public Double getLowScore() {
        return lowScore;
    }

    public void setLowScore(Double lowScore) {
        this.lowScore = lowScore;
    }

}
