package cn.com.qmth.stmms.biz.report.utils.module;

import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

import org.apache.commons.lang.StringUtils;

import cn.com.qmth.stmms.biz.exam.model.ExamQuestion;
import cn.com.qmth.stmms.biz.exam.model.ExamStudent;
import cn.com.qmth.stmms.biz.report.utils.Module;
import cn.com.qmth.stmms.biz.report.utils.QuestionCalculatorProvider;
import cn.com.qmth.stmms.biz.report.utils.ReportContext;
import cn.com.qmth.stmms.biz.report.utils.unit.BaseCalculatorUnit;

/**
 * 按科目+班级维度统计小题难度等级与区分度等级
 * 
 * @author luoshi
 *
 */
public class SubjectClassQuestionLevelModule extends SubjectQuestionLevelModule implements Module {

    protected Map<String, Set<String>> classMap;

    public SubjectClassQuestionLevelModule(ReportContext context, QuestionCalculatorProvider provider) {
        super(context, provider);
    }

    @Override
    public void process(ExamStudent student) {
        super.process(student);

        Set<String> set = classMap.get(student.getSubjectCode());
        if (set == null) {
            set = new HashSet<>();
            classMap.put(student.getSubjectCode(), set);
        }
        set.add(student.getClassName());
    }

    @Override
    protected void beforeSave() {
        for (Entry<String, List<ExamQuestion>> entry : questions.entrySet()) {
            Set<String> classSet = classMap.get(entry.getKey());
            if (classSet.isEmpty()) {
                continue;
            }
            for (String className : classSet) {
                String key = entry.getKey() + "\t" + className;
                for (ExamQuestion question : entry.getValue()) {
                    if (question.getTotalScore() == null || question.getTotalScore() == 0) {
                        continue;
                    }
                    BaseCalculatorUnit calculator = provider.getCalculator(question, className);
                    if (calculator == null) {
                        continue;
                    }
                    // 按全卷维度统计
                    findDifficulityLevelCounter(key).process(question, calculator.difficulty);
                    findDiscriminationLevelCounter(key).process(question, calculator.discrimination);
                    // 按大题维度统计
                    findDifficulityLevelCounter(getGroupKey(question, className)).process(question,
                            calculator.difficulty);
                    findDiscriminationLevelCounter(getGroupKey(question, className)).process(question,
                            calculator.discrimination);
                }
            }
        }
    }

    protected String getGroupKey(ExamQuestion question, String className) {
        return question.getSubjectCode() + "\t" + className + "\t" + question.isObjective() + "\t"
                + StringUtils.trimToEmpty(question.getPaperType()) + "\t" + +question.getMainNumber();
    }

    public void save() {
        super.beforeSave();
        // TODO
    }

}
