package cn.com.qmth.stmms.biz.report.utils.module;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import org.apache.commons.lang.StringUtils;

import cn.com.qmth.stmms.biz.exam.model.ExamQuestion;
import cn.com.qmth.stmms.biz.exam.model.ExamStudent;
import cn.com.qmth.stmms.biz.report.utils.Module;
import cn.com.qmth.stmms.biz.report.utils.QuestionCalculatorProvider;
import cn.com.qmth.stmms.biz.report.utils.ReportContext;
import cn.com.qmth.stmms.biz.report.utils.unit.BaseCalculatorUnit;
import cn.com.qmth.stmms.biz.report.utils.unit.LevelRange;
import cn.com.qmth.stmms.biz.report.utils.unit.QuestionCounter;

/**
 * 按科目统计全样本小题难度等级与区分度等级
 * 
 * @author luoshi
 *
 */
public class SubjectQuestionLevelModule implements Module {

    protected ReportContext context;

    protected QuestionCalculatorProvider provider;

    protected Map<String, List<ExamQuestion>> questions;

    protected Map<String, QuestionCounter> difficulityLevels, discriminationLevels;

    protected LevelRange[] difficulityLevelConfig, discriminationLevelConfig;

    public SubjectQuestionLevelModule(ReportContext context, QuestionCalculatorProvider provider) {
        this.context = context;
        this.provider = provider;
        this.questions = new HashMap<String, List<ExamQuestion>>();
        this.difficulityLevels = new HashMap<String, QuestionCounter>();
        this.discriminationLevels = new HashMap<String, QuestionCounter>();
        this.difficulityLevelConfig = context.getDifficulityLevelConfig();
        this.discriminationLevelConfig = context.getDiscriminationLevelConfig();
    }

    @Override
    public void process(ExamStudent student) {
        String key = student.getSubjectCode() + "\t" + StringUtils.trimToEmpty(student.getPaperType());
        List<ExamQuestion> list = questions.get(key);
        if (list == null) {
            list = new ArrayList<ExamQuestion>();
            questions.put(key, list);
            list.addAll(student.getObjectiveQuestionList());
            list.addAll(student.getSubjectiveQuestionList());
        }
    }

    @Override
    public void save() {
        beforeSave();
        // TODO 补充保存到数据库逻辑
    }

    protected void beforeSave() {
        for (Entry<String, List<ExamQuestion>> entry : questions.entrySet()) {
            String key = entry.getKey();
            for (ExamQuestion question : entry.getValue()) {
                if (question.getTotalScore() == null || question.getTotalScore() == 0) {
                    continue;
                }
                BaseCalculatorUnit calculator = provider.getCalculator(question);
                if (calculator == null) {
                    continue;
                }
                // 按全卷维度统计
                findDifficulityLevelCounter(key).process(question, calculator.difficulty);
                findDiscriminationLevelCounter(key).process(question, calculator.discrimination);
                // 按大题维度统计
                findDifficulityLevelCounter(getGroupKey(question)).process(question, calculator.difficulty);
                findDiscriminationLevelCounter(getGroupKey(question)).process(question, calculator.discrimination);
            }
        }
    }

    protected String getGroupKey(ExamQuestion question) {
        return question.getSubjectCode() + "\t" + question.isObjective() + "\t"
                + StringUtils.trimToEmpty(question.getPaperType()) + "\t" + question.getMainNumber();
    }

    protected QuestionCounter findDifficulityLevelCounter(String key) {
        QuestionCounter counter = difficulityLevels.get(key);
        if (counter == null) {
            counter = new QuestionCounter(difficulityLevelConfig);
            difficulityLevels.put(key, counter);
        }
        return counter;
    }

    protected QuestionCounter findDiscriminationLevelCounter(String key) {
        QuestionCounter counter = discriminationLevels.get(key);
        if (counter == null) {
            counter = new QuestionCounter(discriminationLevelConfig);
            discriminationLevels.put(key, counter);
        }
        return counter;
    }

}
