package cn.com.qmth.stmms.biz.report.utils.module;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;

import cn.com.qmth.stmms.biz.exam.model.ExamQuestion;
import cn.com.qmth.stmms.biz.exam.model.ExamStudent;
import cn.com.qmth.stmms.biz.report.utils.Module;
import cn.com.qmth.stmms.biz.report.utils.ReportContext;
import cn.com.qmth.stmms.biz.report.utils.unit.OptionCounter;

/**
 * 按科目统计全样本小题选项指标
 * 
 * @author luoshi
 *
 */
public class SubjectQuestionOptionModule implements Module {

    private Map<String, OptionCounter> counters;

    private ReportContext context;

    public SubjectQuestionOptionModule(ReportContext context) {
        this.counters = new HashMap<String, OptionCounter>();
        this.context = context;
    }

    public void process(ExamStudent student) {
        if (student.isUpload() && !student.isAbsent() && !student.isBreach() && student.getSubject() != null) {
            // 遍历客观题
            process(student, student.getAnswerList(), student.getObjectiveQuestionList());
        }
    }

    private void process(ExamStudent student, List<String> answerList, List<ExamQuestion> questionList) {
        if (answerList == null || questionList == null) {
            return;
        }
        int answerCount = answerList.size();
        for (int i = 0; i < questionList.size(); i++) {
            ExamQuestion question = questionList.get(i);
            if (question.getTotalScore() == null || question.getTotalScore() == 0) {
                // 跳过填充试题
                continue;
            }
            // 有实际作答才需要进行选项分析
            if (answerCount > i) {
                findCounter(getKey(student, question), question).process(answerList.get(i));
            }
        }
    }

    public String getKey(ExamStudent student, ExamQuestion question) {
        return question.getSubjectCode() + "\t" + question.isObjective() + "\t"
                + StringUtils.trimToEmpty(question.getPaperType()) + "\t" + question.getMainNumber() + "\t"
                + question.getSubNumber();
    }

    public void save() {
        // TODO 需要补充选项分析结果保存
    }

    private OptionCounter findCounter(String key, ExamQuestion question) {
        OptionCounter counter = counters.get(key);
        if (counter == null) {
            counter = new OptionCounter(question.getAnswer().length() > 1);
            counters.put(key, counter);
        }
        return counter;
    }

}
